@@ -1,4 +1,5 @@
 /* libwnck header */
+/* vim: set sw=2 et: */
 
 /*
  * Copyright (C) 2001 Havoc Pennington
@@ -22,17 +23,21 @@
 #ifndef WNCK_LIB_H
 #define WNCK_LIB_H
 
-#include <libwnck/application.h>
-#include <libwnck/screen.h>
-#include <libwnck/util.h>
 #include <libwnck/window.h>
+#include <libwnck/application.h>
+#include <libwnck/class-group.h>
 #include <libwnck/workspace.h>
-#include <libwnck/wnck-enum-types.h>
+#include <libwnck/screen.h>
 
 #include <libwnck/pager.h>
 #include <libwnck/tasklist.h>
 #include <libwnck/selector.h>
 
+#include <libwnck/window-action-menu.h>
+#include <libwnck/util.h>
+
+#include <libwnck/wnck-enum-types.h>
+
 #endif /* WNCK_LIB_H */
 
 
